
# ultimateEda
With This Library  You can do the EDA(Exploroty data analysis)



## version
0.0.1
## Authors

- [@RANJIT_MAITY](https://www.linkedin.com/in/ranjit-maity-75204a131/)


## Reales Date 
 13-02-2022
 
 


## Badges

[![MIT License](https://img.shields.io/apm/l/atomic-design-ui.svg?)](https://github.com/tterb/atomic-design-ui/blob/master/LICENSEs)
[![GPLv3 License](https://img.shields.io/badge/License-GPL%20v3-yellow.svg)](https://opensource.org/licenses/)
[![AGPL License](https://img.shields.io/badge/license-AGPL-blue.svg)](http://www.gnu.org/licenses/agpl-3.0)


## 🚀 About Me
I Am Ranjit From INDIA, a Certified Data scientist , Data Engineer by professional  with hands-on experience of more than 1year and 2months ,on ML> NLP> Data mining > Neural Networks > ModeL Deployment>ETL.
 Give me raw data and I'll return you insights, problems to be rectified and enhancements to achieve the target. I am always on the lookout for new projects to work And 
Am Always Happy ☻ To Play With Data


## 🔗 Links

[![linkedin](https://img.shields.io/badge/linkedin-0A66C2?style=for-the-badge&logo=linkedin&logoColor=white)](https://www.linkedin.com/in/ranjit-maity-75204a131/)
[![twitter](https://img.shields.io/badge/twitter-1DA1F2?style=for-the-badge&logo=twitter&logoColor=white)](https://twitter.com/ranjitmaity95)


## Demo

- YOU HAVE TO CALL THE EDA finction and pass your DATAFRANE(DF).
    cool SEAT BACK RELAX.




## Usage/Examples

```python
! pip install ultimateEda
```
```python
import ultimateEda as ue
```
```python
result=ue.eda.EDA(df)
#Your Dataframe
#It will return a Dataframe 

```
```python
result
#to look to the result dataframe

```